==> haskell-gtk2hs-buildtools-0.13.4.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk2hs-buildtools
version: 0.13.4.0
id: gtk2hs-buildtools-0.13.4.0-gAZVhkcolTFigkopqajR4
key: gtk2hs-buildtools-0.13.4.0-gAZVhkcolTFigkopqajR4
license: GPL-2
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-devel@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Tools to build the Gtk2Hs suite of User Interface libraries.
description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.
category: Development
author: Axel Simon, Duncan Coutts, Manuel Chakravaty
exposed: True
indefinite: False
exposed-modules:
    Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules: Paths_gtk2hs_buildtools BaseVersion Config Errors
                Binary DLists FastMutInt FileOps FNameOps Map Position Set UNames
                CIO State StateBase StateTrans Attributes Idents NameSpaces Lexers
                C CAST CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty
                CTokens CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader
                C2HSState Switches C2HSConfig Version
abi: c2ba42556d38b8363af6ff48d3e02a3b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gtk2hs-buildtools-0.13.4.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/gtk2hs-buildtools-0.13.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-gtk2hs-buildtools
hs-libraries: HSgtk2hs-buildtools-0.13.4.0-gAZVhkcolTFigkopqajR4
depends:
    base-4.10.1.0 process-1.6.1.0 array-0.5.2.0 pretty-1.1.3.3
    filepath-1.4.1.2 random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We Cabal-2.0.1.0
    directory-1.3.0.2 containers-0.5.10.2
    hashtables-1.2.3.0-7TdqUBBYHAbAAjykzazpkH
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             Cabal-2.0.1.0=a6a7b28e8794af4ab0796ef93b162aed
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashtables-1.2.3.0-7TdqUBBYHAbAAjykzazpkH=32a405226bbbbccf15e0a3785c334a72
haddock-interfaces: /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock
haddock-html: /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk2hs-buildtools-0.13.4.0-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk2hs-buildtools
version: 0.13.4.0
id: gtk2hs-buildtools-0.13.4.0-2SKMIrUzdYq6tqNctDCDIP
key: gtk2hs-buildtools-0.13.4.0-2SKMIrUzdYq6tqNctDCDIP
license: GPL-2.0-only
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-devel@lists.sourceforge.net
author: Axel Simon, Duncan Coutts, Manuel Chakravaty
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Tools to build the Gtk2Hs suite of User Interface libraries.
description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.
category: Development
abi: fd862c32589cb7e9c474639a1af49e67
exposed: True
exposed-modules:
    Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules: Paths_gtk2hs_buildtools BaseVersion Config Errors
                Binary DLists FastMutInt FileOps FNameOps Map Position Set UNames
                CIO State StateBase StateTrans Attributes Idents NameSpaces Lexers
                C CAST CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty
                CTokens CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader
                C2HSState Switches C2HSConfig Version
import-dirs: /usr/lib/ghc-8.4.3/site-local/gtk2hs-buildtools-0.13.4.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/gtk2hs-buildtools-0.13.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-gtk2hs-buildtools
hs-libraries: HSgtk2hs-buildtools-0.13.4.0-2SKMIrUzdYq6tqNctDCDIP
depends:
    base-4.11.1.0 process-1.6.3.0 array-0.5.2.0 pretty-1.1.3.6
    filepath-1.4.2 random-1.1-9LLJAJa4iQFLJiLXBOBXBV Cabal-2.2.0.1
    directory-1.3.1.5 containers-0.5.11.0
    hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             Cabal-2.2.0.1=e1424ba639ad8048b22840c690086176
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg=9716e82ce2a1119e069e6c69de7a6cc9
haddock-interfaces: /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock
haddock-html: /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
